@@ -30,8 +30,8 @@ FormMagick uses the C<Locale::Maketext> module for L10N.  It stores its
 translations for each language in a hash like this:
 
   %Lexicon = (
-	"Hello"		=> "Bonjour",
-	"Click here"	=> "Appuyez ici"
+    "Hello"     => "Bonjour",
+    "Click here"    => "Appuyez ici"
   );
 
 You can add your own entries to any language lexicon using the
@@ -71,16 +71,8 @@ Templates, you will have to explicitly call the l10n routines.
 
 =head2 add_lexicon($lang, $lexicon_hashref)
 
-This method takes two arguments.  The first is a two-letter string
-representing the language to which entries should be added.  These are
-standard ISO language abbreviations, eg "en" for English, "fr" for
-French, "de" for German, etc.  
-
-The second argument is a hashref in which the keys of the hash are the 
-phrases to be translated and the values are the translations.
-
-For more information about how localization (L10N) works in FormMagick,
-see C<CGI::FormMagick::L10N>.
+This method is deprecated and will be removed in CGI::FormMagick 0.60 in
+favour of an XML-based lexicon.
 
 =begin testing
 BEGIN: {
@@ -91,23 +83,15 @@ BEGIN: {
 
 $ENV{HTTP_ACCEPT_LANGUAGE} = $ENV{LANG} = $ENV{LANGUAGE} = "fr";
 
-my $xml = qq(
-  <FORM TITLE="FormMagick demo application" POST-EVENT="submit_order">
-    <PAGE NAME="Personal" TITLE="Personal details" POST-EVENT="lookup_group_info">
-      <FIELD ID="firstname" LABEL="first name" TYPE="TEXT" VALIDATION="nonblank"/>
-    </PAGE>
-  </FORM>
-);
-
-ok ($fm = new CGI::FormMagick(TYPE => 'STRING', SOURCE => $xml), "created fm object");
+ok ($fm = new CGI::FormMagick(TYPE => 'FILE', SOURCE => "t/simple.xml"), "created fm object");
 
 ok( $fm->add_lexicon("fr", { "yes" => "oui" })     , "Simple add_lexicon");
 ok( not($fm->add_lexicon("fr", "abc" ))  , "Non-hashref lexicon should fail");
 ok( not($fm->add_lexicon("fr", (1,2,3))) , "Non-hashref lexicon should fail");
 ok( not($fm->add_lexicon("fr", [1,2,3])) , "Non-hashref lexicon should fail");
 TODO: {
-	local $TODO = "Haven't yet implemented tests for non-existent languages";
-	ok( not($fm->add_lexicon("xx", { yes => 'oui' }))     , "Non-existent language should fail");
+    local $TODO = "Haven't yet implemented tests for non-existent languages";
+    ok( not($fm->add_lexicon("xx", { yes => 'oui' }))     , "Non-existent language should fail");
 }
 
 =end testing
@@ -115,31 +99,34 @@ TODO: {
 =cut
 
 sub add_lexicon {
-	my ($self, $lang, $lexicon_hashref) = @_;
 
-	return undef unless ref($lexicon_hashref) eq "HASH";
+    warn "WARNING: add_lexicon is deprecated, and will be removed in FormMagick 0.60\n";
 
-	# much reference nastiness to point to the Lexicon we want to change
-	# ... couldn't have done this without Schuyler's help.  Ergh.
-	# XXX needs work, no doubt
+    my ($self, $lang, $lexicon_hashref) = @_;
 
-	no strict 'refs';
-	my $changeme = "CGI::FormMagick::L10N::${lang}::Lexicon"; 
+    return undef unless ref($lexicon_hashref) eq "HASH";
 
-	# XXX somewhere here we have to check if $changeme exists, but that's
-	# *hard*
+    # much reference nastiness to point to the Lexicon we want to change
+    # ... couldn't have done this without Schuyler's help.  Ergh.
+    # XXX needs work, no doubt
 
-	my $hard_ref = \%$changeme;
+    no strict 'refs';
+    my $changeme = "CGI::FormMagick::L10N::${lang}::Lexicon"; 
+    
+    # XXX somewhere here we have to check if $changeme exists, but that's
+    # *hard*
 
-	while (my ($a, $b) = each %$lexicon_hashref) {
-		$hard_ref->{$a} = $b;
-	}
-	use strict 'refs';
+    my $hard_ref = \%$changeme;
+    
+    while (my ($a, $b) = each %$lexicon_hashref) {
+        $hard_ref->{$a} = $b;
+    }
+    use strict 'refs';
 
-	#debug($self, "Our two refs are $hard_ref and $lex_ref");
-	#debug($self, "foo is " . $self->localise("foo"));
-	#debug($self, "Error is " . $self->localise("Error"));
-	return 1;
+    #debug($self, "Our two refs are $hard_ref and $lex_ref");
+    #debug($self, "foo is " . $self->localise("foo"));
+    #debug($self, "Error is " . $self->localise("Error"));
+    return 1;
 }
 
 
@@ -156,6 +143,10 @@ Translates a string into the end-user's preferred language by checking
 their HTTP_ACCEPT_LANG variable and pushing it through
 Locale::Maketext
 
+WARNING WARNING WARNING: The internals of this routine will change 
+significantly in version 0.60, when we remove Locale::Maketext from 
+the equation.  However, its output should still be the same.  Just FYI.
+
 =for testing
 is($fm->localise("yes"), "oui", "Simple localisation");
 is($fm->localise("xyz"), "xyz", "Attempted localisation of untranslated string");
@@ -165,42 +156,47 @@ is($fm->localise(""),    "",    "Fail gracefully on localisation of empty string
 =cut
 
 sub localise {
-	my $fm = shift;
-	my $string = shift || "";
-	if (my $localised_string = $fm->{language}->maketext($string)) {
-		return $localised_string;
-	} else {
-		warn "L10N warning: No localisation string found for '$string' for language $ENV{HTTP_ACCEPT_LANGUAGE}";
-		return $string;
-	}
+    my $fm = shift;
+    my $string = shift || "";
+    ($string) = ($string =~ /(.*)/s);
+    warn "String is $string\n";
+    if (my $localised_string = $fm->{language}->maketext($string)) {
+        return $localised_string;
+    } else {
+        warn "L10N warning: No localisation string found for '$string' for language $ENV{HTTP_ACCEPT_LANGUAGE}";
+        return $string;
+    }
 }
 
 =pod
 
 =head2 check_l10n()
 
-print out lexica to check whether they're what you think they are
-this is mostly for debugging purposes
+print out lexicons to check whether they're what you think they are
+this is mostly for debugging purposes.  If you have DEBUG set to 1 in
+your call to the new() method, you'll see a link at the bottom of each
+page that says "Check L10N".  This is the subroutine that's called when
+you follow that link.
 
 =cut
 
 sub check_l10n {
-	my $self = shift;
-	print qq( <p>Your choice of language: $ENV{HTTP_ACCEPT_LANGUAGE}</p>);
-	my @langs = split(/, /, $ENV{HTTP_ACCEPT_LANGUAGE});
-	foreach my $lang (@langs) {
-		print qq(<h2>Language: $lang</h2>);
+    my $self = shift;
+    print qq( <p>Your choice of language: $ENV{HTTP_ACCEPT_LANGUAGE}</p>);
+    my @langs = split(/, /, $ENV{HTTP_ACCEPT_LANGUAGE});
+    foreach my $lang (@langs) {
+        print qq(<h2>Language: $lang</h2>);
 
-		no strict 'refs';
-		my $lex= "CGI::FormMagick::L10N::${lang}::Lexicon";
-		debug($self, "Lexicon name is $lex");
-		debug($self, scalar(keys %$lex) . " keys in lexicon");
-		foreach my $term (keys %$lex) {
-			print qq(<p>$term<br>
-				<i>$lex->{$term}</i></p>);
-		}			
-		use strict 'refs';
-	}
+        no strict 'refs';
+        my $lex= "CGI::FormMagick::L10N::${lang}::Lexicon";
+        debug($self, "Lexicon name is $lex");
+        debug($self, scalar(keys %$lex) . " keys in lexicon");
+        foreach my $term (keys %$lex) {
+            print qq(<p>$term<br>
+                <i>$lex->{$term}</i></p>);
+        } 
+        use strict 'refs';
+    }
 }
 
 =pod 
